# immutabledict

![PyPI](https://img.shields.io/pypi/v/immutabledict) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/immutabledict) ![License](https://img.shields.io/pypi/l/immutabledict) ![Build](https://img.shields.io/travis/com/corenting/immutabledict) ![Codecov](https://img.shields.io/codecov/c/github/corenting/immutabledict) ![PyPI - Downloads](https://img.shields.io/pypi/dm/immutabledict)

A fork of ``frozendict``, an immutable wrapper around dictionaries.

See the original project here: https://github.com/slezica/python-frozendict .

## Differences with frozendict

- Dropped support of Python 2
- Fixed `collections.Mapping` deprecation warning
